# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.iam.v1 import key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/key_service.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%yandex/cloud/iam/v1/key_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/iam/v1/key.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\"\xa6\x01\n\x0fListKeysRequest\x12.\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\x12$\n\x12service_account_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"S\n\x10ListKeysResponse\x12&\n\x04keys\x18\x01 \x03(\x0b\x32\x18.yandex.cloud.iam.v1.Key\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x01\n\x10\x43reateKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\x12\x39\n\rkey_algorithm\x18\x04 \x01(\x0e\x32\".yandex.cloud.iam.v1.Key.Algorithm\"O\n\x11\x43reateKeyResponse\x12%\n\x03key\x18\x01 \x01(\x0b\x32\x18.yandex.cloud.iam.v1.Key\x12\x13\n\x0bprivate_key\x18\x02 \x01(\t\"\x81\x01\n\x10UpdateKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"#\n\x11UpdateKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"0\n\x10\x44\x65leteKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"#\n\x11\x44\x65leteKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"w\n\x18ListKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"k\n\x19ListKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*\x19\n\tKeyFormat\x12\x0c\n\x08PEM_FILE\x10\x00\x32\x9e\x06\n\nKeyService\x12\x62\n\x03Get\x12\".yandex.cloud.iam.v1.GetKeyRequest\x1a\x18.yandex.cloud.iam.v1.Key\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/iam/v1/keys/{key_id}\x12i\n\x04List\x12$.yandex.cloud.iam.v1.ListKeysRequest\x1a%.yandex.cloud.iam.v1.ListKeysResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/iam/v1/keys\x12p\n\x06\x43reate\x12%.yandex.cloud.iam.v1.CreateKeyRequest\x1a&.yandex.cloud.iam.v1.CreateKeyResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/iam/v1/keys:\x01*\x12\x90\x01\n\x06Update\x12%.yandex.cloud.iam.v1.UpdateKeyRequest\x1a!.yandex.cloud.operation.Operation\"<\x82\xd3\xe4\x93\x02\x1a\x32\x15/iam/v1/keys/{key_id}:\x01*\xb2\xd2*\x18\n\x11UpdateKeyMetadata\x12\x03Key\x12\x9f\x01\n\x06\x44\x65lete\x12%.yandex.cloud.iam.v1.DeleteKeyRequest\x1a!.yandex.cloud.operation.Operation\"K\x82\xd3\xe4\x93\x02\x17*\x15/iam/v1/keys/{key_id}\xb2\xd2**\n\x11\x44\x65leteKeyMetadata\x12\x15google.protobuf.Empty\x12\x99\x01\n\x0eListOperations\x12-.yandex.cloud.iam.v1.ListKeyOperationsRequest\x1a..yandex.cloud.iam.v1.ListKeyOperationsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /iam/v1/keys/{key_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_KEYFORMAT = _descriptor.EnumDescriptor(
  name='KeyFormat',
  full_name='yandex.cloud.iam.v1.KeyFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PEM_FILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1376,
  serialized_end=1401,
)
_sym_db.RegisterEnumDescriptor(_KEYFORMAT)

KeyFormat = enum_type_wrapper.EnumTypeWrapper(_KEYFORMAT)
PEM_FILE = 0



_GETKEYREQUEST = _descriptor.Descriptor(
  name='GetKeyRequest',
  full_name='yandex.cloud.iam.v1.GetKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.GetKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='yandex.cloud.iam.v1.GetKeyRequest.format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=355,
)


_LISTKEYSREQUEST = _descriptor.Descriptor(
  name='ListKeysRequest',
  full_name='yandex.cloud.iam.v1.ListKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='yandex.cloud.iam.v1.ListKeysRequest.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.ListKeysRequest.service_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListKeysRequest.page_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListKeysRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=524,
)


_LISTKEYSRESPONSE = _descriptor.Descriptor(
  name='ListKeysResponse',
  full_name='yandex.cloud.iam.v1.ListKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='yandex.cloud.iam.v1.ListKeysResponse.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=609,
)


_CREATEKEYREQUEST = _descriptor.Descriptor(
  name='CreateKeyRequest',
  full_name='yandex.cloud.iam.v1.CreateKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.CreateKeyRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.CreateKeyRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='yandex.cloud.iam.v1.CreateKeyRequest.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_algorithm', full_name='yandex.cloud.iam.v1.CreateKeyRequest.key_algorithm', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=807,
)


_CREATEKEYRESPONSE = _descriptor.Descriptor(
  name='CreateKeyResponse',
  full_name='yandex.cloud.iam.v1.CreateKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iam.v1.CreateKeyResponse.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.iam.v1.CreateKeyResponse.private_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=888,
)


_UPDATEKEYREQUEST = _descriptor.Descriptor(
  name='UpdateKeyRequest',
  full_name='yandex.cloud.iam.v1.UpdateKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.UpdateKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.iam.v1.UpdateKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.UpdateKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=1020,
)


_UPDATEKEYMETADATA = _descriptor.Descriptor(
  name='UpdateKeyMetadata',
  full_name='yandex.cloud.iam.v1.UpdateKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.UpdateKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1057,
)


_DELETEKEYREQUEST = _descriptor.Descriptor(
  name='DeleteKeyRequest',
  full_name='yandex.cloud.iam.v1.DeleteKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.DeleteKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1059,
  serialized_end=1107,
)


_DELETEKEYMETADATA = _descriptor.Descriptor(
  name='DeleteKeyMetadata',
  full_name='yandex.cloud.iam.v1.DeleteKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.DeleteKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1144,
)


_LISTKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListKeyOperationsRequest',
  full_name='yandex.cloud.iam.v1.ListKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.iam.v1.ListKeyOperationsRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.ListKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.ListKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1265,
)


_LISTKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListKeyOperationsResponse',
  full_name='yandex.cloud.iam.v1.ListKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.iam.v1.ListKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.ListKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1374,
)

_GETKEYREQUEST.fields_by_name['format'].enum_type = _KEYFORMAT
_LISTKEYSREQUEST.fields_by_name['format'].enum_type = _KEYFORMAT
_LISTKEYSRESPONSE.fields_by_name['keys'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2._KEY
_CREATEKEYREQUEST.fields_by_name['format'].enum_type = _KEYFORMAT
_CREATEKEYREQUEST.fields_by_name['key_algorithm'].enum_type = yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2._KEY_ALGORITHM
_CREATEKEYRESPONSE.fields_by_name['key'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2._KEY
_UPDATEKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetKeyRequest'] = _GETKEYREQUEST
DESCRIPTOR.message_types_by_name['ListKeysRequest'] = _LISTKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListKeysResponse'] = _LISTKEYSRESPONSE
DESCRIPTOR.message_types_by_name['CreateKeyRequest'] = _CREATEKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateKeyResponse'] = _CREATEKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateKeyRequest'] = _UPDATEKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateKeyMetadata'] = _UPDATEKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteKeyRequest'] = _DELETEKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteKeyMetadata'] = _DELETEKEYMETADATA
DESCRIPTOR.message_types_by_name['ListKeyOperationsRequest'] = _LISTKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListKeyOperationsResponse'] = _LISTKEYOPERATIONSRESPONSE
DESCRIPTOR.enum_types_by_name['KeyFormat'] = _KEYFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeyRequest = _reflection.GeneratedProtocolMessageType('GetKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.GetKeyRequest)
  })
_sym_db.RegisterMessage(GetKeyRequest)

ListKeysRequest = _reflection.GeneratedProtocolMessageType('ListKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListKeysRequest)
  })
_sym_db.RegisterMessage(ListKeysRequest)

ListKeysResponse = _reflection.GeneratedProtocolMessageType('ListKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListKeysResponse)
  })
_sym_db.RegisterMessage(ListKeysResponse)

CreateKeyRequest = _reflection.GeneratedProtocolMessageType('CreateKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateKeyRequest)
  })
_sym_db.RegisterMessage(CreateKeyRequest)

CreateKeyResponse = _reflection.GeneratedProtocolMessageType('CreateKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKEYRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateKeyResponse)
  })
_sym_db.RegisterMessage(CreateKeyResponse)

UpdateKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateKeyRequest)
  })
_sym_db.RegisterMessage(UpdateKeyRequest)

UpdateKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.UpdateKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateKeyMetadata)

DeleteKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteKeyRequest)
  })
_sym_db.RegisterMessage(DeleteKeyRequest)

DeleteKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.DeleteKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteKeyMetadata)

ListKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListKeyOperationsRequest)

ListKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.ListKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListKeyOperationsResponse)


DESCRIPTOR._options = None
_GETKEYREQUEST.fields_by_name['key_id']._options = None
_LISTKEYSREQUEST.fields_by_name['service_account_id']._options = None
_LISTKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTKEYSREQUEST.fields_by_name['page_token']._options = None
_CREATEKEYREQUEST.fields_by_name['service_account_id']._options = None
_CREATEKEYREQUEST.fields_by_name['description']._options = None
_UPDATEKEYREQUEST.fields_by_name['key_id']._options = None
_UPDATEKEYREQUEST.fields_by_name['description']._options = None
_DELETEKEYREQUEST.fields_by_name['key_id']._options = None
_LISTKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
_LISTKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_KEYSERVICE = _descriptor.ServiceDescriptor(
  name='KeyService',
  full_name='yandex.cloud.iam.v1.KeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1404,
  serialized_end=2202,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.iam.v1.KeyService.Get',
    index=0,
    containing_service=None,
    input_type=_GETKEYREQUEST,
    output_type=yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2._KEY,
    serialized_options=b'\202\323\344\223\002\027\022\025/iam/v1/keys/{key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.iam.v1.KeyService.List',
    index=1,
    containing_service=None,
    input_type=_LISTKEYSREQUEST,
    output_type=_LISTKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/iam/v1/keys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iam.v1.KeyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEKEYREQUEST,
    output_type=_CREATEKEYRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\014/iam/v1/keys:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.iam.v1.KeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\0322\025/iam/v1/keys/{key_id}:\001*\262\322*\030\n\021UpdateKeyMetadata\022\003Key',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.iam.v1.KeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\027*\025/iam/v1/keys/{key_id}\262\322**\n\021DeleteKeyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.iam.v1.KeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTKEYOPERATIONSREQUEST,
    output_type=_LISTKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /iam/v1/keys/{key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYSERVICE)

DESCRIPTOR.services_by_name['KeyService'] = _KEYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/opensearch/v1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/opensearch/v1/auth.proto',
  package='yandex.cloud.mdb.opensearch.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/mdb/opensearch/v1/auth.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1dyandex/cloud/validation.proto\"J\n\x0c\x41uthSettings\x12:\n\x04saml\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.opensearch.v1.SAMLSettings\"\xeb\x01\n\x0cSAMLSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12 \n\ridp_entity_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12&\n\x11idp_metadata_file\x18\x03 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=10000\x12\x1f\n\x0csp_entity_id\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12!\n\x0e\x64\x61shboards_url\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1c\n\troles_key\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1e\n\x0bsubject_key\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=250Bs\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_AUTHSETTINGS = _descriptor.Descriptor(
  name='AuthSettings',
  full_name='yandex.cloud.mdb.opensearch.v1.AuthSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saml', full_name='yandex.cloud.mdb.opensearch.v1.AuthSettings.saml', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=182,
)


_SAMLSETTINGS = _descriptor.Descriptor(
  name='SAMLSettings',
  full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idp_entity_id', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.idp_entity_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idp_metadata_file', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.idp_metadata_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=10000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_entity_id', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.sp_entity_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dashboards_url', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.dashboards_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles_key', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.roles_key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_key', full_name='yandex.cloud.mdb.opensearch.v1.SAMLSettings.subject_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=250', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=420,
)

_AUTHSETTINGS.fields_by_name['saml'].message_type = _SAMLSETTINGS
DESCRIPTOR.message_types_by_name['AuthSettings'] = _AUTHSETTINGS
DESCRIPTOR.message_types_by_name['SAMLSettings'] = _SAMLSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthSettings = _reflection.GeneratedProtocolMessageType('AuthSettings', (_message.Message,), {
  'DESCRIPTOR' : _AUTHSETTINGS,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.auth_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.AuthSettings)
  })
_sym_db.RegisterMessage(AuthSettings)

SAMLSettings = _reflection.GeneratedProtocolMessageType('SAMLSettings', (_message.Message,), {
  'DESCRIPTOR' : _SAMLSETTINGS,
  '__module__' : 'yandex.cloud.mdb.opensearch.v1.auth_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.opensearch.v1.SAMLSettings)
  })
_sym_db.RegisterMessage(SAMLSettings)


DESCRIPTOR._options = None
_SAMLSETTINGS.fields_by_name['idp_entity_id']._options = None
_SAMLSETTINGS.fields_by_name['idp_metadata_file']._options = None
_SAMLSETTINGS.fields_by_name['sp_entity_id']._options = None
_SAMLSETTINGS.fields_by_name['dashboards_url']._options = None
_SAMLSETTINGS.fields_by_name['roles_key']._options = None
_SAMLSETTINGS.fields_by_name['subject_key']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/service_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import service_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/service_service.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/billing/v1/service_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a%yandex/cloud/billing/v1/service.proto\x1a\x1dyandex/cloud/validation.proto\"-\n\x11GetServiceRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"o\n\x13ListServicesRequest\x12\x1a\n\x06\x66ilter\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x14ListServicesResponse\x12\x32\n\x08services\x18\x01 \x03(\x0b\x32 .yandex.cloud.billing.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x8c\x02\n\x0eServiceService\x12v\n\x03Get\x12*.yandex.cloud.billing.v1.GetServiceRequest\x1a .yandex.cloud.billing.v1.Service\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/billing/v1/services/{id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.billing.v1.ListServicesRequest\x1a-.yandex.cloud.billing.v1.ListServicesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/billing/v1/servicesBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_service__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='yandex.cloud.billing.v1.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.GetServiceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=219,
)


_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='yandex.cloud.billing.v1.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.ListServicesRequest.filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListServicesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListServicesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=332,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='yandex.cloud.billing.v1.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yandex.cloud.billing.v1.ListServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListServicesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=433,
)

_LISTSERVICESRESPONSE.fields_by_name['services'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_service__pb2._SERVICE
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.service_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.service_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.service_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)


DESCRIPTOR._options = None
_GETSERVICEREQUEST.fields_by_name['id']._options = None
_LISTSERVICESREQUEST.fields_by_name['filter']._options = None
_LISTSERVICESREQUEST.fields_by_name['page_size']._options = None
_LISTSERVICESREQUEST.fields_by_name['page_token']._options = None

_SERVICESERVICE = _descriptor.ServiceDescriptor(
  name='ServiceService',
  full_name='yandex.cloud.billing.v1.ServiceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=436,
  serialized_end=704,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.billing.v1.ServiceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=yandex_dot_cloud_dot_billing_dot_v1_dot_service__pb2._SERVICE,
    serialized_options=b'\202\323\344\223\002\033\022\031/billing/v1/services/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.billing.v1.ServiceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/billing/v1/services',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICESERVICE)

DESCRIPTOR.services_by_name['ServiceService'] = _SERVICESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/origin_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/origin_service.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/cdn/v1/origin_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"N\n\x10GetOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"V\n\x12ListOriginsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"C\n\x13ListOriginsResponse\x12,\n\x07origins\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.cdn.v1.Origin\"\xfd\x01\n\x13\x43reateOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1c\n\x06source\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x62\x61\x63kup\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x04meta\x18\x06 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\"R\n\x14\x43reateOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xb1\x01\n\x13UpdateOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0e\n\x06\x62\x61\x63kup\x18\x05 \x01(\x08\x12-\n\x04meta\x18\x06 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\"R\n\x14UpdateOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1f\n\x0forigin_group_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"Q\n\x13\x44\x65leteOriginRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\torigin_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"1\n\x14\x44\x65leteOriginMetadata\x12\x19\n\torigin_id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\xd9\x05\n\rOriginService\x12n\n\x03Get\x12%.yandex.cloud.cdn.v1.GetOriginRequest\x1a\x1b.yandex.cloud.cdn.v1.Origin\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cdn/v1/origins/{origin_id}\x12r\n\x04List\x12\'.yandex.cloud.cdn.v1.ListOriginsRequest\x1a(.yandex.cloud.cdn.v1.ListOriginsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/cdn/v1/origins\x12\x93\x01\n\x06\x43reate\x12(.yandex.cloud.cdn.v1.CreateOriginRequest\x1a!.yandex.cloud.operation.Operation\"<\x82\xd3\xe4\x93\x02\x14\"\x0f/cdn/v1/origins:\x01*\xb2\xd2*\x1e\n\x14\x43reateOriginMetadata\x12\x06Origin\x12\x9f\x01\n\x06Update\x12(.yandex.cloud.cdn.v1.UpdateOriginRequest\x1a!.yandex.cloud.operation.Operation\"H\x82\xd3\xe4\x93\x02 2\x1b/cdn/v1/origins/{origin_id}:\x01*\xb2\xd2*\x1e\n\x14UpdateOriginMetadata\x12\x06Origin\x12\xab\x01\n\x06\x44\x65lete\x12(.yandex.cloud.cdn.v1.DeleteOriginRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02\x1d*\x1b/cdn/v1/origins/{origin_id}\xb2\xd2*-\n\x14\x44\x65leteOriginMetadata\x12\x15google.protobuf.EmptyBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETORIGINREQUEST = _descriptor.Descriptor(
  name='GetOriginRequest',
  full_name='yandex.cloud.cdn.v1.GetOriginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetOriginRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.GetOriginRequest.origin_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=344,
)


_LISTORIGINSREQUEST = _descriptor.Descriptor(
  name='ListOriginsRequest',
  full_name='yandex.cloud.cdn.v1.ListOriginsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ListOriginsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.ListOriginsRequest.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=432,
)


_LISTORIGINSRESPONSE = _descriptor.Descriptor(
  name='ListOriginsResponse',
  full_name='yandex.cloud.cdn.v1.ListOriginsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origins', full_name='yandex.cloud.cdn.v1.ListOriginsResponse.origins', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=501,
)


_CREATEORIGINREQUEST = _descriptor.Descriptor(
  name='CreateOriginRequest',
  full_name='yandex.cloud.cdn.v1.CreateOriginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.backup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='yandex.cloud.cdn.v1.CreateOriginRequest.meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=757,
)


_CREATEORIGINMETADATA = _descriptor.Descriptor(
  name='CreateOriginMetadata',
  full_name='yandex.cloud.cdn.v1.CreateOriginMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.CreateOriginMetadata.origin_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.CreateOriginMetadata.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=841,
)


_UPDATEORIGINREQUEST = _descriptor.Descriptor(
  name='UpdateOriginRequest',
  full_name='yandex.cloud.cdn.v1.UpdateOriginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.origin_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backup', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.backup', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='yandex.cloud.cdn.v1.UpdateOriginRequest.meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=1021,
)


_UPDATEORIGINMETADATA = _descriptor.Descriptor(
  name='UpdateOriginMetadata',
  full_name='yandex.cloud.cdn.v1.UpdateOriginMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.UpdateOriginMetadata.origin_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.UpdateOriginMetadata.origin_group_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1105,
)


_DELETEORIGINREQUEST = _descriptor.Descriptor(
  name='DeleteOriginRequest',
  full_name='yandex.cloud.cdn.v1.DeleteOriginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.DeleteOriginRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.DeleteOriginRequest.origin_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1188,
)


_DELETEORIGINMETADATA = _descriptor.Descriptor(
  name='DeleteOriginMetadata',
  full_name='yandex.cloud.cdn.v1.DeleteOriginMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_id', full_name='yandex.cloud.cdn.v1.DeleteOriginMetadata.origin_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1239,
)

_LISTORIGINSRESPONSE.fields_by_name['origins'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGIN
_CREATEORIGINREQUEST.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CREATEORIGINREQUEST.fields_by_name['backup'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CREATEORIGINREQUEST.fields_by_name['meta'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINMETA
_UPDATEORIGINREQUEST.fields_by_name['meta'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINMETA
DESCRIPTOR.message_types_by_name['GetOriginRequest'] = _GETORIGINREQUEST
DESCRIPTOR.message_types_by_name['ListOriginsRequest'] = _LISTORIGINSREQUEST
DESCRIPTOR.message_types_by_name['ListOriginsResponse'] = _LISTORIGINSRESPONSE
DESCRIPTOR.message_types_by_name['CreateOriginRequest'] = _CREATEORIGINREQUEST
DESCRIPTOR.message_types_by_name['CreateOriginMetadata'] = _CREATEORIGINMETADATA
DESCRIPTOR.message_types_by_name['UpdateOriginRequest'] = _UPDATEORIGINREQUEST
DESCRIPTOR.message_types_by_name['UpdateOriginMetadata'] = _UPDATEORIGINMETADATA
DESCRIPTOR.message_types_by_name['DeleteOriginRequest'] = _DELETEORIGINREQUEST
DESCRIPTOR.message_types_by_name['DeleteOriginMetadata'] = _DELETEORIGINMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetOriginRequest = _reflection.GeneratedProtocolMessageType('GetOriginRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORIGINREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetOriginRequest)
  })
_sym_db.RegisterMessage(GetOriginRequest)

ListOriginsRequest = _reflection.GeneratedProtocolMessageType('ListOriginsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORIGINSREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListOriginsRequest)
  })
_sym_db.RegisterMessage(ListOriginsRequest)

ListOriginsResponse = _reflection.GeneratedProtocolMessageType('ListOriginsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORIGINSRESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListOriginsResponse)
  })
_sym_db.RegisterMessage(ListOriginsResponse)

CreateOriginRequest = _reflection.GeneratedProtocolMessageType('CreateOriginRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORIGINREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateOriginRequest)
  })
_sym_db.RegisterMessage(CreateOriginRequest)

CreateOriginMetadata = _reflection.GeneratedProtocolMessageType('CreateOriginMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORIGINMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateOriginMetadata)
  })
_sym_db.RegisterMessage(CreateOriginMetadata)

UpdateOriginRequest = _reflection.GeneratedProtocolMessageType('UpdateOriginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORIGINREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateOriginRequest)
  })
_sym_db.RegisterMessage(UpdateOriginRequest)

UpdateOriginMetadata = _reflection.GeneratedProtocolMessageType('UpdateOriginMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORIGINMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateOriginMetadata)
  })
_sym_db.RegisterMessage(UpdateOriginMetadata)

DeleteOriginRequest = _reflection.GeneratedProtocolMessageType('DeleteOriginRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORIGINREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteOriginRequest)
  })
_sym_db.RegisterMessage(DeleteOriginRequest)

DeleteOriginMetadata = _reflection.GeneratedProtocolMessageType('DeleteOriginMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORIGINMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.origin_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteOriginMetadata)
  })
_sym_db.RegisterMessage(DeleteOriginMetadata)


DESCRIPTOR._options = None
_GETORIGINREQUEST.fields_by_name['folder_id']._options = None
_GETORIGINREQUEST.fields_by_name['origin_id']._options = None
_LISTORIGINSREQUEST.fields_by_name['folder_id']._options = None
_LISTORIGINSREQUEST.fields_by_name['origin_group_id']._options = None
_CREATEORIGINREQUEST.fields_by_name['folder_id']._options = None
_CREATEORIGINREQUEST.fields_by_name['origin_group_id']._options = None
_CREATEORIGINREQUEST.fields_by_name['source']._options = None
_CREATEORIGINMETADATA.fields_by_name['origin_id']._options = None
_CREATEORIGINMETADATA.fields_by_name['origin_group_id']._options = None
_UPDATEORIGINREQUEST.fields_by_name['folder_id']._options = None
_UPDATEORIGINREQUEST.fields_by_name['origin_id']._options = None
_UPDATEORIGINMETADATA.fields_by_name['origin_id']._options = None
_UPDATEORIGINMETADATA.fields_by_name['origin_group_id']._options = None
_DELETEORIGINREQUEST.fields_by_name['folder_id']._options = None
_DELETEORIGINREQUEST.fields_by_name['origin_id']._options = None
_DELETEORIGINMETADATA.fields_by_name['origin_id']._options = None

_ORIGINSERVICE = _descriptor.ServiceDescriptor(
  name='OriginService',
  full_name='yandex.cloud.cdn.v1.OriginService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1242,
  serialized_end=1971,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.cdn.v1.OriginService.Get',
    index=0,
    containing_service=None,
    input_type=_GETORIGINREQUEST,
    output_type=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGIN,
    serialized_options=b'\202\323\344\223\002\035\022\033/cdn/v1/origins/{origin_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.cdn.v1.OriginService.List',
    index=1,
    containing_service=None,
    input_type=_LISTORIGINSREQUEST,
    output_type=_LISTORIGINSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/cdn/v1/origins',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.cdn.v1.OriginService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEORIGINREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\024\"\017/cdn/v1/origins:\001*\262\322*\036\n\024CreateOriginMetadata\022\006Origin',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.cdn.v1.OriginService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEORIGINREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/cdn/v1/origins/{origin_id}:\001*\262\322*\036\n\024UpdateOriginMetadata\022\006Origin',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.cdn.v1.OriginService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEORIGINREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/cdn/v1/origins/{origin_id}\262\322*-\n\024DeleteOriginMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORIGINSERVICE)

DESCRIPTOR.services_by_name['OriginService'] = _ORIGINSERVICE

# @@protoc_insertion_point(module_scope)



import time

from yandexcloud._operation_waiter import OperationWaiter


class _OperationMock:
    def __init__(self, done):
        self.id = "some_id"
        self.done = done


class _WaitTenIterations:
    def __init__(self):
        self.__get_count = 0

    def Get(self, id):
        self.__get_count += 1
        return _OperationMock(done=self.__get_count > 10)


def test_ten_iterations():
    waiter = OperationWaiter("", _WaitTenIterations())

    count = 0
    for _ in waiter:
        count += 1

    assert waiter.operation.done
    assert count == 10


class _NeverDone:
    def Get(self, id):
        return _OperationMock(done=False)


def test_timeout():
    waiter = OperationWaiter("", _NeverDone(), timeout=10)

    for _ in waiter:
        time.sleep(1)

    assert waiter.operation.done is False




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dns/v1/dns_zone.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dns/v1/dns_zone.proto',
  package='yandex.cloud.dns.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/dns/v1/dns_zone.proto\x12\x13yandex.cloud.dns.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x02\n\x07\x44nsZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.dns.v1.DnsZone.LabelsEntry\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12\x42\n\x12private_visibility\x18\x08 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\t \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\tRecordSet\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-254\x12\x16\n\x04type\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04\x31-20\x12\x1d\n\x03ttl\x18\x03 \x01(\x03\x42\x10\xfa\xc7\x31\x0c\x30-2147483647\x12$\n\x04\x64\x61ta\x18\x04 \x03(\tB\x16\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x05\x31-255\x90\xc8\x31\x01\"=\n\x11PrivateVisibility\x12(\n\x0bnetwork_ids\x18\x01 \x03(\tB\x13\x82\xc8\x31\x05\x30-100\x8a\xc8\x31\x02\x32\x30\x90\xc8\x31\x01\"\x12\n\x10PublicVisibilityBV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_DNSZONE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dns.v1.DnsZone.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=500,
)

_DNSZONE = _descriptor.Descriptor(
  name='DnsZone',
  full_name='yandex.cloud.dns.v1.DnsZone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.dns.v1.DnsZone.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.dns.v1.DnsZone.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.dns.v1.DnsZone.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.DnsZone.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.dns.v1.DnsZone.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.dns.v1.DnsZone.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='yandex.cloud.dns.v1.DnsZone.zone', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_visibility', full_name='yandex.cloud.dns.v1.DnsZone.private_visibility', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_visibility', full_name='yandex.cloud.dns.v1.DnsZone.public_visibility', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DNSZONE_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=500,
)


_RECORDSET = _descriptor.Descriptor(
  name='RecordSet',
  full_name='yandex.cloud.dns.v1.RecordSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.RecordSet.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0051-254', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.dns.v1.RecordSet.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0041-20', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.dns.v1.RecordSet.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0140-2147483647', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.dns.v1.RecordSet.data', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0051-100\212\3101\0051-255\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=632,
)


_PRIVATEVISIBILITY = _descriptor.Descriptor(
  name='PrivateVisibility',
  full_name='yandex.cloud.dns.v1.PrivateVisibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_ids', full_name='yandex.cloud.dns.v1.PrivateVisibility.network_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0050-100\212\3101\00220\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=695,
)


_PUBLICVISIBILITY = _descriptor.Descriptor(
  name='PublicVisibility',
  full_name='yandex.cloud.dns.v1.PublicVisibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=715,
)

_DNSZONE_LABELSENTRY.containing_type = _DNSZONE
_DNSZONE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DNSZONE.fields_by_name['labels'].message_type = _DNSZONE_LABELSENTRY
_DNSZONE.fields_by_name['private_visibility'].message_type = _PRIVATEVISIBILITY
_DNSZONE.fields_by_name['public_visibility'].message_type = _PUBLICVISIBILITY
DESCRIPTOR.message_types_by_name['DnsZone'] = _DNSZONE
DESCRIPTOR.message_types_by_name['RecordSet'] = _RECORDSET
DESCRIPTOR.message_types_by_name['PrivateVisibility'] = _PRIVATEVISIBILITY
DESCRIPTOR.message_types_by_name['PublicVisibility'] = _PUBLICVISIBILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsZone = _reflection.GeneratedProtocolMessageType('DnsZone', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DNSZONE_LABELSENTRY,
    '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DnsZone.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DNSZONE,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DnsZone)
  })
_sym_db.RegisterMessage(DnsZone)
_sym_db.RegisterMessage(DnsZone.LabelsEntry)

RecordSet = _reflection.GeneratedProtocolMessageType('RecordSet', (_message.Message,), {
  'DESCRIPTOR' : _RECORDSET,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.RecordSet)
  })
_sym_db.RegisterMessage(RecordSet)

PrivateVisibility = _reflection.GeneratedProtocolMessageType('PrivateVisibility', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEVISIBILITY,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.PrivateVisibility)
  })
_sym_db.RegisterMessage(PrivateVisibility)

PublicVisibility = _reflection.GeneratedProtocolMessageType('PublicVisibility', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICVISIBILITY,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.PublicVisibility)
  })
_sym_db.RegisterMessage(PublicVisibility)


DESCRIPTOR._options = None
_DNSZONE_LABELSENTRY._options = None
_RECORDSET.fields_by_name['name']._options = None
_RECORDSET.fields_by_name['type']._options = None
_RECORDSET.fields_by_name['ttl']._options = None
_RECORDSET.fields_by_name['data']._options = None
_PRIVATEVISIBILITY.fields_by_name['network_ids']._options = None
# @@protoc_insertion_point(module_scope)
